==> apache-linkis-1.7.0-src.tar.gz: apache-linkis-1.7.0-src/docs/configuration/linkis-gateway-core.md <==
## linkis-gateway-core configure


| Module Name (Service Name) | Parameter Name | Default Value | Description |Used|
| -------- | -------- | ----- |----- |  -----   |
|linkis-gateway-core|wds.linkis.gateway.conf.enable.proxy.user |false|gateway.conf.enable.proxy.user|
|linkis-gateway-core|wds.linkis.gateway.conf.proxy.user.config|proxy.properties|proxy.user.config|
|linkis-gateway-core|wds.linkis.gateway.conf.proxy.user.scan.interval|1000 * 60 * 10|gateway.conf.proxy.user.scan.interval|
|linkis-gateway-core|wds.linkis.gateway.conf.enable.token.auth| false |gateway.conf.enable.token.auth|
|linkis-gateway-core|wds.linkis.gateway.conf.token.auth.scan.interval|1000 * 60 * 10 |gateway.conf.token.auth.scan.interval|
|linkis-gateway-core|wds.linkis.gateway.conf.url.pass.auth|  |gateway.conf.url.pass.auth  |
|linkis-gateway-core|wds.linkis.gateway.conf.enable.sso|false| gateway.conf.enable.sso |
|linkis-gateway-core|wds.linkis.gateway.conf.sso.interceptor|   |gateway.conf.sso.interceptor|
|linkis-gateway-core|wds.linkis.admin.user| hadoop |admin.user |
|linkis-gateway-core|wds.linkis.admin.password|  |admin.password|
|linkis-gateway-core|wds.linkis.gateway.usercontrol_switch_on|false|gateway.usercontrol_switch_on|
|linkis-gateway-core|wds.linkis.gateway.publickey.url|http://127.0.0.1:8088| gateway.publickey.url |
|linkis-gateway-core|wds.linkis.gateway.conf.proxy.user.list|  | gateway.conf.proxy.user.list|
|linkis-gateway-core|wds.linkis.usercontrol.application.name|cloud-usercontrol| usercontrol.application.name|
|linkis-gateway-core|wds.linkis.login_encrypt.enable| false |login_encrypt.enable|
|linkis-gateway-core|wds.linkis.entrance.name| linkis-cg-entrance|entrance.name|
|linkis-gateway-core|wds.linkis.enable.gateway.auth|false|gateway.auth|
|linkis-gateway-core|wds.linkis.gateway.auth.file| auth.txt |gateway.auth.file|
|linkis-gateway-core|wds.linkis.gateway.access.token| WS-AUTH|gateway.access.token|
|linkis-gateway-core|wds.linkis.gateway.control.workspace.ids| 224 | gateway.control.workspace.ids|
|linkis-gateway-core|wds.dss.query.workspace.service|dss-framework-project-server| workspace.service|
|linkis-gateway-core|wds.linkis.user.workspace.reflesh.time| 10 |reflesh.time|
|linkis-gateway-core|wds.linkis.gateway.server.reflesh.enabled|false |gateway.server.reflesh.enabled|
|linkis-gateway-core|wds.linkis.gateway.header.allow.origin|*|gateway.header.allow.origin|
|linkis-gateway-core|wds.linkis.gateway.header.allow.methods| POST, GET, OPTIONS, PUT, HEAD, DELETE |gateway.header.allow.methods|
|linkis-gateway-core|wds.linkis.gateway.domain.level| 3|gateway.domain.level|
|linkis-gateway-core|wds.linkis.gateway.domain.level| 3|gateway.domain.level|
|linkis-gateway-core|wds.linkis.gateway.cookie.domain.setup.switch|false|gateway.cookie.domain.setup.switch|
|linkis-gateway-core|wds.linkis.gateway.no.auth.url.regex| .*visualis.*share.* |gateway.no.auth.url.regex|
|linkis-gateway-core|wds.linkis.gateway.this.url|   |gateway.this.url|
|linkis-gateway-core|wds.linkis.gateway.this.schema|   | gateway.this.schema|
|linkis-gateway-core|wds.linkis.web.enable.water.mark|true| web.enable.water.mark|
|linkis-gateway-core|wds.linkis.entrance.name|   |linkis.entrance.name|

==> apache-linkis-1.8.0-src.tar.gz: apache-linkis-1.8.0-src/docs/configuration/linkis-gateway-core.md <==
## linkis-gateway-core configure


| Module Name (Service Name) | Parameter Name | Default Value | Description |Used|
| -------- | -------- | ----- |----- |  -----   |
|linkis-gateway-core|wds.linkis.gateway.conf.enable.proxy.user |false|gateway.conf.enable.proxy.user|
|linkis-gateway-core|wds.linkis.gateway.conf.proxy.user.config|proxy.properties|proxy.user.config|
|linkis-gateway-core|wds.linkis.gateway.conf.proxy.user.scan.interval|1000 * 60 * 10|gateway.conf.proxy.user.scan.interval|
|linkis-gateway-core|wds.linkis.gateway.conf.enable.token.auth| false |gateway.conf.enable.token.auth|
|linkis-gateway-core|wds.linkis.gateway.conf.token.auth.scan.interval|1000 * 60 * 10 |gateway.conf.token.auth.scan.interval|
|linkis-gateway-core|wds.linkis.gateway.conf.url.pass.auth|  |gateway.conf.url.pass.auth  |
|linkis-gateway-core|wds.linkis.gateway.conf.enable.sso|false| gateway.conf.enable.sso |
|linkis-gateway-core|wds.linkis.gateway.conf.sso.interceptor|   |gateway.conf.sso.interceptor|
|linkis-gateway-core|wds.linkis.admin.user| hadoop |admin.user |
|linkis-gateway-core|wds.linkis.admin.password|  |admin.password|
|linkis-gateway-core|wds.linkis.gateway.usercontrol_switch_on|false|gateway.usercontrol_switch_on|
|linkis-gateway-core|wds.linkis.gateway.publickey.url|http://127.0.0.1:8088| gateway.publickey.url |
|linkis-gateway-core|wds.linkis.gateway.conf.proxy.user.list|  | gateway.conf.proxy.user.list|
|linkis-gateway-core|wds.linkis.usercontrol.application.name|cloud-usercontrol| usercontrol.application.name|
|linkis-gateway-core|wds.linkis.login_encrypt.enable| false |login_encrypt.enable|
|linkis-gateway-core|wds.linkis.entrance.name| linkis-cg-entrance|entrance.name|
|linkis-gateway-core|wds.linkis.enable.gateway.auth|false|gateway.auth|
|linkis-gateway-core|wds.linkis.gateway.auth.file| auth.txt |gateway.auth.file|
|linkis-gateway-core|wds.linkis.gateway.access.token| WS-AUTH|gateway.access.token|
|linkis-gateway-core|wds.linkis.gateway.control.workspace.ids| 224 | gateway.control.workspace.ids|
|linkis-gateway-core|wds.dss.query.workspace.service|dss-framework-project-server| workspace.service|
|linkis-gateway-core|wds.linkis.user.workspace.reflesh.time| 10 |reflesh.time|
|linkis-gateway-core|wds.linkis.gateway.server.reflesh.enabled|false |gateway.server.reflesh.enabled|
|linkis-gateway-core|wds.linkis.gateway.header.allow.origin|*|gateway.header.allow.origin|
|linkis-gateway-core|wds.linkis.gateway.header.allow.methods| POST, GET, OPTIONS, PUT, HEAD, DELETE |gateway.header.allow.methods|
|linkis-gateway-core|wds.linkis.gateway.domain.level| 3|gateway.domain.level|
|linkis-gateway-core|wds.linkis.gateway.domain.level| 3|gateway.domain.level|
|linkis-gateway-core|wds.linkis.gateway.cookie.domain.setup.switch|false|gateway.cookie.domain.setup.switch|
|linkis-gateway-core|wds.linkis.gateway.no.auth.url.regex| .*visualis.*share.* |gateway.no.auth.url.regex|
|linkis-gateway-core|wds.linkis.gateway.this.url|   |gateway.this.url|
|linkis-gateway-core|wds.linkis.gateway.this.schema|   | gateway.this.schema|
|linkis-gateway-core|wds.linkis.web.enable.water.mark|true| web.enable.water.mark|
|linkis-gateway-core|wds.linkis.entrance.name|   |linkis.entrance.name|
|linkis-gateway-core|wds.linkis.gateway.conf.enable.oauth.auth| false  |wds.linkis.gateway.conf.enable.oauth.auth|
|linkis-gateway-core|wds.linkis.gateway.auth.oauth.authentication.url|  |wds.linkis.gateway.auth.oauth.authentication.url|
|linkis-gateway-core|wds.linkis.gateway.auth.oauth.exchange.url|  |wds.linkis.gateway.auth.oauth.exchange.url|
|linkis-gateway-core|wds.linkis.gateway.auth.oauth.validate.url|  |wds.linkis.gateway.auth.oauth.validate.url|
|linkis-gateway-core|wds.linkis.gateway.auth.oauth.validate.field|  |wds.linkis.gateway.auth.oauth.validate.field|
|linkis-gateway-core|wds.linkis.gateway.auth.oauth.client.id|  |wds.linkis.gateway.auth.oauth.client.id|
|linkis-gateway-core|wds.linkis.gateway.auth.oauth.client.secret|  |wds.linkis.gateway.auth.oauth.client.secret|
|linkis-gateway-core|wds.linkis.gateway.auth.oauth.scope|  |wds.linkis.gateway.auth.oauth.scope|
